@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package HTML::Widget::Plugin::Button;
-use base qw(HTML::Widget::Plugin);
+
+use HTML::Widget::Plugin ();
+BEGIN { our @ISA = 'HTML::Widget::Plugin' };
 
 =head1 NAME
 
@@ -11,11 +13,11 @@ HTML::Widget::Plugin::Button - a button for clicking
 
 =head1 VERSION
 
-version 0.056
+version 0.061
 
 =cut
 
-our $VERSION = '0.056';
+our $VERSION = '0.061';
 
 =head1 DESCRIPTION
 
