@@ -3,7 +3,9 @@ use strict;
 use warnings;
 
 package HTML::Widget::Plugin::Password;
-use base qw(HTML::Widget::Plugin::Input);
+
+use HTML::Widget::Plugin::Input ();
+BEGIN { our @ISA = 'HTML::Widget::Plugin::Input' };
 
 =head1 NAME
 
@@ -11,11 +13,11 @@ HTML::Widget::Plugin::Password - for SECRET input
 
 =head1 VERSION
 
-version 0.055
+version 0.061
 
 =cut
 
-our $VERSION = '0.055';
+our $VERSION = '0.061';
 
 =head1 DESCRIPTION
 
